#11900: Serious regression caused by #9138
-------------------------------------------------------------------+--------
Reporter: SimonKing |
Owner: tbd
Type: defect |
Status: needs_work
Priority: critical |
Milestone: sage-4.8
Component: performance |
Keywords: categories regression
Work_issues: Rebase first patch rel #9562; update reviewer patch |
Upstream: N/A
Reviewer: Jeroen Demeyer, Nicolas M. Thiéry |
Author: Simon King, Nicolas M. Thiéry
Merged: |
Dependencies: #9138 #11911
-------------------------------------------------------------------+--------
Changes (by SimonKing):
* work_issues: Doctest errors, rebase rel #9562 => Rebase first patch
rel #9562; update reviewer patch
Comment:
Both our patches need to be change. Namely, I need to rebase mine because
of #9562 and you need to modify yours, because it introduces the two
errors that I indicated in the previous post.
First error: By my patch, `_value` is a cdef attribute of constant
functions, thus, one can not access it in a doc test. Therefore, I had
changed the corresponding doctest. But your patch re-introduces that test.
So, please remove the hunk
{{{
diff --git a/sage/misc/constant_function.pyx
b/sage/misc/constant_function.pyx
--- a/sage/misc/constant_function.pyx
+++ b/sage/misc/constant_function.pyx
@@ -64,7 +64,7 @@ cdef class ConstantFunction(SageObject):
"""
EXAMPLES::
- sage: ConstantFunction(1)()
+ sage: ConstantFunction(1)._value
1
"""
self._value = value
}}}
from your patch.
Second error: There is one error message saying "base ring must be a
field." But your reviewer patch changes one example, so that the same
error message is expected ''without'' the dot in the end.
I am talking about the hunk
{{{
diff --git a/sage/categories/vector_spaces.py
b/sage/categories/vector_spaces.py
--- a/sage/categories/vector_spaces.py
+++ b/sage/categories/vector_spaces.py
@@ -32,36 +32,33 @@ class VectorSpaces(Category_module):
...
...
sage: VectorSpaces(ZZ)
Traceback (most recent call last):
...
- AssertionError: The base ring must be a field.
+ AssertionError: The base ring must be a field
+ With ``check=False``, the check is disabled, possibly enabling
+ incorrect inputs::
+
+ sage: VectorSpaces(ZZ, check=False)
+ Category of vector spaces over Integer Ring
}}}
--
Ticket URL: <http://trac.sagemath.org/sage_trac/ticket/11900#comment:175>
Sage <http://www.sagemath.org>
Sage: Creating a Viable Open Source Alternative to Magma, Maple, Mathematica,
and MATLAB
--
You received this message because you are subscribed to the Google Groups
"sage-trac" group.
To post to this group, send email to [email protected].
To unsubscribe from this group, send email to
[email protected].
For more options, visit this group at
http://groups.google.com/group/sage-trac?hl=en.